@@ -4,19 +4,34 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 import asyncio
-from collections.abc import Callable
+from collections.abc import Awaitable, Callable
 import logging
 import sys
-from typing import Any, Awaitable, Dict, Final, Optional, Tuple
+from typing import Any, Final, Optional, Tuple
 
 from serial import SerialException
 import serial_asyncio
 
-from . import requests, responses
-from .constants import DATA_MIXERS, DEFAULT_IP, DEFAULT_NETMASK, WLAN_ENCRYPTION
-from .devices import ECOMAX_ADDRESS, DevicesCollection
+from .constants import (
+    DATA_MIXERS,
+    DATA_MODULES,
+    DATA_NETWORK,
+    DATA_PASSWORD,
+    DATA_PRODUCT,
+    DATA_SCHEMA,
+    ECOMAX_ADDRESS,
+)
+from .devices import DeviceCollection
 from .exceptions import ConnectionFailedError, FrameError, FrameTypeError
-from .frame import Frame
+from .frames import Frame, messages, requests, responses
+from .helpers.network_info import (
+    DEFAULT_IP,
+    DEFAULT_NETMASK,
+    WLAN_ENCRYPTION_NONE,
+    EthernetParameters,
+    NetworkInfo,
+    WirelessParameters,
+)
 from .stream import FrameReader, FrameWriter
 
 _LOGGER = logging.getLogger(__name__)
@@ -45,10 +60,10 @@ class Connection(ABC):
             **kwargs -- keyword arguments for connection driver
         """
         self.kwargs = kwargs
-        self.closing = False
-        self.writer = None
-        self._net = {}
-        self._devices = DevicesCollection()
+        self.closing: bool = False
+        self.writer: Optional[FrameWriter] = None
+        self._network = NetworkInfo()
+        self._devices = DeviceCollection()
         self._callback_task = None
         self._callback_closed = None
 
@@ -61,7 +76,7 @@ class Connection(ABC):
 
     async def _callback(
         self,
-        callback: Callable[[DevicesCollection, Connection], Awaitable[Any]],
+        callback: Callable[[DeviceCollection, Connection], Awaitable[Any]],
         interval: int,
     ) -> None:
         """Calls provided callback method with specified interval.
@@ -95,29 +110,31 @@ class Connection(ABC):
             writer.queue(frame.response())
 
         elif isinstance(frame, responses.UID):
-            device.uid = frame.data["UID"]
-            device.product = frame.data["reg_name"]
+            device.product = frame.data[DATA_PRODUCT]
 
         elif isinstance(frame, responses.Password):
-            device.password = frame.data
+            device.password = frame.data[DATA_PASSWORD]
 
-        elif isinstance(frame, (responses.RegData, responses.CurrentData)):
+        elif isinstance(frame, messages.CurrentData):
+            device.set_data(frame.data)
+            device.mixers.set_data(frame.data[DATA_MIXERS])
+            device.modules = frame.data[DATA_MODULES]
+
+        elif isinstance(frame, messages.RegData):
             frame.schema = device.schema
             device.set_data(frame.data)
-            if DATA_MIXERS in frame.data:
-                device.mixers.set_data(frame.data[DATA_MIXERS])
 
-        elif isinstance(frame, responses.Parameters):
+        elif isinstance(frame, responses.BoilerParameters):
             device.set_parameters(frame.data)
 
         elif isinstance(frame, responses.MixerParameters):
             device.mixers.set_parameters(frame.data[DATA_MIXERS])
 
         elif isinstance(frame, responses.DataSchema):
-            device.schema = frame.data
+            device.schema = frame.data[DATA_SCHEMA]
 
         elif isinstance(frame, requests.CheckDevice):
-            writer.queue(frame.response(data=self._net))
+            writer.queue(frame.response(data={DATA_NETWORK: self._network}))
 
         writer.collect(device.changes)
 
@@ -130,8 +147,8 @@ class Connection(ABC):
         while True:
             if self.closing:
                 await self.writer.close()
-                await self._close()
-                return False
+                await self.force_close()
+                break
 
             try:
                 frame = await reader.read()
@@ -141,13 +158,14 @@ class Connection(ABC):
                 _LOGGER.warning("Frame error: %s", e)
             else:
                 asyncio.create_task(self._process(frame, self.writer))
+            finally:
                 await self.writer.process_queue()
 
-        return True
+        return False
 
     async def task(
         self,
-        callback: Callable[[DevicesCollection, Connection], Awaitable[Any]],
+        callback: Callable[[DeviceCollection, Connection], Awaitable[Any]],
         interval: int = 1,
         reconnect_on_failure: bool = True,
     ) -> None:
@@ -181,20 +199,22 @@ class Connection(ABC):
                     "Connection to device failed, retrying in %i seconds...",
                     RECONNECT_TIMEOUT,
                 )
-                await self._close()
+                await self.force_close()
                 await asyncio.sleep(RECONNECT_TIMEOUT)
 
-    async def _close(self) -> None:
+    async def force_close(self) -> None:
         """Declares connection as closed."""
-        await self.async_close()
         self.writer = None
         self.closing = False
+        if self._callback_task is not None:
+            self._callback_task.cancel()
+
         if self._callback_closed is not None:
             await self._callback_closed(self)
 
     def run(
         self,
-        callback: Callable[[DevicesCollection, Connection], Awaitable[Any]],
+        callback: Callable[[DeviceCollection, Connection], Awaitable[Any]],
         interval: int = 1,
         reconnect_on_failure: bool = True,
     ) -> None:
@@ -226,18 +246,15 @@ class Connection(ABC):
             netmask -- netmask of eth device
             gateway -- gateway address of eth device
         """
-        eth: Dict[str, Any] = {}
-        eth["ip"] = ip
-        eth["netmask"] = netmask
-        eth["gateway"] = gateway
-        eth["status"] = True
-        self._net["eth"] = eth
+        self._network.eth = EthernetParameters(
+            ip=ip, netmask=netmask, gateway=gateway, status=True
+        )
 
     def set_wlan(
         self,
         ssid: str,
         ip: str,
-        encryption: int = WLAN_ENCRYPTION[1],
+        encryption: int = WLAN_ENCRYPTION_NONE,
         netmask: str = DEFAULT_NETMASK,
         gateway: str = DEFAULT_IP,
         quality: int = 100,
@@ -252,15 +269,15 @@ class Connection(ABC):
             netmask -- netmask of wlan device
             gateway -- gateway address of wlan device
         """
-        wlan: Dict[str, Any] = {}
-        wlan["ssid"] = ssid
-        wlan["encryption"] = encryption
-        wlan["quality"] = quality
-        wlan["ip"] = ip
-        wlan["netmask"] = netmask
-        wlan["gateway"] = gateway
-        wlan["status"] = True
-        self._net["wlan"] = wlan
+        self._network.wlan = WirelessParameters(
+            ssid=ssid,
+            encryption=encryption,
+            quality=quality,
+            ip=ip,
+            netmask=netmask,
+            gateway=gateway,
+            status=True,
+        )
 
     def on_closed(
         self, callback: Optional[Callable[[Connection], Awaitable[Any]]] = None
@@ -276,14 +293,17 @@ class Connection(ABC):
         """Closes connection."""
         if not self.closing:
             self.closing = True
-            if self._callback_task is not None:
-                self._callback_task.cancel()
 
     async def async_close(self) -> None:
         """Closes connection asynchronously."""
         loop = asyncio.get_running_loop()
         await loop.run_in_executor(None, self.close)
 
+    @property
+    def devices(self) -> DeviceCollection:
+        """Returns collection of devices."""
+        return self._devices
+
     @property
     def closed(self) -> bool:
         """Returns connection state."""
