@@ -2,12 +2,12 @@
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
-from typing import Final
+from typing import Final, Optional, Union
 
 from . import util
 
 
-class Type(ABC):
+class DataType(ABC):
     """Base representation of data type.
 
     Attributes:
@@ -15,9 +15,11 @@ class Type(ABC):
         _data -- type bytes
     """
 
-    _data = bytearray()
+    _data: Union[bytes, bytearray] = bytearray()
 
-    def __init__(self, data=None, size: int = None):
+    def __init__(
+        self, data: Optional[Union[bytes, bytearray]] = None, size: Optional[int] = None
+    ):
         """Creates data type instance.
 
         Keyword arguments:
@@ -30,15 +32,23 @@ class Type(ABC):
         if data is not None:
             self._data = data[0:size] if size > 0 else data
 
+    def __eq__(self, other) -> bool:
+        """Checks if two data types are equal.
+
+        Keyword arguments:
+            other -- data type to compare to
+        """
+        return self._data == other._data and self.size == other.size
+
     def __repr__(self) -> str:
         """Returns serializable string representation of the class."""
         return f"""{self.__class__.__name__}(
-    data = {self._data},
+    data = {self._data!r},
     size = {self.size}
 )
 """.strip()
 
-    def unpack(self, data):
+    def unpack(self, data: Union[bytes, bytearray]):
         """Unpacks data to a given type.
 
         Keyword arguments:
@@ -57,7 +67,7 @@ class Type(ABC):
         """Returns data size in bytes."""
 
 
-class Undefined0(Type):
+class Undefined0(DataType):
     """Undefined zero-byte representation."""
 
     @property
@@ -71,7 +81,7 @@ class Undefined0(Type):
         return 0
 
 
-class SignedChar(Type):
+class SignedChar(DataType):
     """Char representation."""
 
     @property
@@ -85,7 +95,7 @@ class SignedChar(Type):
         return 1
 
 
-class Short(Type):
+class Short(DataType):
     """16 bit integer representation."""
 
     @property
@@ -99,7 +109,7 @@ class Short(Type):
         return 2
 
 
-class Int(Type):
+class Int(DataType):
     """32 bit integer representation."""
 
     @property
@@ -113,7 +123,7 @@ class Int(Type):
         return 4
 
 
-class Byte(Type):
+class Byte(DataType):
     """Byte representation."""
 
     @property
@@ -127,7 +137,7 @@ class Byte(Type):
         return 1
 
 
-class UnsignedShort(Type):
+class UnsignedShort(DataType):
     """Unsigned 16 bit integer representation."""
 
     @property
@@ -141,7 +151,7 @@ class UnsignedShort(Type):
         return 2
 
 
-class UnsignedInt(Type):
+class UnsignedInt(DataType):
     """Unsigned 32 bit integer representation."""
 
     @property
@@ -155,7 +165,7 @@ class UnsignedInt(Type):
         return 4
 
 
-class Float(Type):
+class Float(DataType):
     """Float representation."""
 
     @property
@@ -169,7 +179,7 @@ class Float(Type):
         return 4
 
 
-class Undefined8(Type):
+class Undefined8(DataType):
     """Undefined representation."""
 
     @property
@@ -183,7 +193,7 @@ class Undefined8(Type):
         return 0
 
 
-class Double(Type):
+class Double(DataType):
     """Double representation."""
 
     @property
@@ -197,7 +207,7 @@ class Double(Type):
         return 8
 
 
-class Boolean(Type):
+class Boolean(DataType):
     """Boolean representation.
 
     Attributes:
@@ -206,7 +216,9 @@ class Boolean(Type):
         _index -- bit array index
     """
 
-    def __init__(self, data=None, size: int = None):
+    def __init__(
+        self, data: Optional[Union[bytes, bytearray]] = None, size: Optional[int] = None
+    ):
         """Creates boolean instance.
 
         Keyword arguments:
@@ -224,7 +236,7 @@ class Boolean(Type):
         self._index = index
         return 0 if self._index == 7 else self._index + 1
 
-    def unpack(self, data) -> None:
+    def unpack(self, data: Union[bytes, bytearray]) -> None:
         """Unpacks data to with given type.
 
         Keyword arguments:
@@ -243,7 +255,7 @@ class Boolean(Type):
         return 1 if self._index == 7 else 0
 
 
-class Int64(Type):
+class Int64(DataType):
     """64 bit signed integer representation."""
 
     @property
@@ -257,7 +269,7 @@ class Int64(Type):
         return 8
 
 
-class UInt64(Type):
+class UInt64(DataType):
     """64 bit unsigned integer representation."""
 
     @property
@@ -271,7 +283,7 @@ class UInt64(Type):
         return 8
 
 
-class IPv4(Type):
+class IPv4(DataType):
     """IPv4 address representation."""
 
     @property
@@ -285,7 +297,7 @@ class IPv4(Type):
         return 4
 
 
-class IPv6(Type):
+class IPv6(DataType):
     """IPv6 address representation."""
 
     @property
@@ -299,14 +311,16 @@ class IPv6(Type):
         return 16
 
 
-class String(Type):
+class String(DataType):
     """Variable length bytes representation."""
 
-    def __init__(self, data=None, size: int = None):
+    def __init__(
+        self, data: Optional[Union[bytes, bytearray]] = None, size: Optional[int] = None
+    ):
         """Creates variable length type instance."""
         super().__init__(data, size=-1)
 
-    def unpack(self, data):
+    def unpack(self, data: Union[bytes, bytearray]):
         """Unpacks data to a given type.
 
         Keyword arguments:
