@@ -2,27 +2,41 @@
 from __future__ import annotations
 
 from abc import abstractmethod
+from collections.abc import Iterable
 import time
 from typing import Any, Dict, Final, List, Optional, Tuple, Type
 
-from . import requests
 from .constants import (
-    DATA_FRAMES,
+    DATA_FAN_POWER,
     DATA_FUEL_CONSUMPTION,
+    DATA_FUEL_LEVEL,
+    DATA_LOAD,
     DATA_MODE,
-    DEVICE_DATA,
-    DEVICE_PARAMS,
-    MODULE_A,
-    PARAM_BOILER_CONTROL,
+    DATA_POWER,
+    DATA_THERMOSTAT,
+    DATA_TRANSMISSION,
+    DATA_UNKNOWN,
+    ECOMAX_ADDRESS,
+    ECOSTER_ADDRESS,
 )
-from .frame import Request
+from .data_types import DataType
+from .frames import Request, requests
 from .helpers.base_device import BaseDevice
 from .helpers.parameter import Parameter
-from .mixers import MixersCollection
+from .helpers.product_info import ConnectedModules, ProductInfo
+from .mixers import MixerCollection
 from .storage import FrameBucket
-
-ECOMAX_ADDRESS: Final = 0x45
-ECOSTER_ADDRESS: Final = 0x51
+from .structures import (
+    alarms,
+    device_parameters,
+    frame_versions,
+    lambda_,
+    output_flags,
+    outputs,
+    statuses,
+    temperatures,
+    thermostats,
+)
 
 MODE_OFF: Final = 0
 MODE_FANNING: Final = 1
@@ -41,6 +55,25 @@ MODES: Final = (
     "Standby",
 )
 
+DEVICE_DATA: List[str] = [
+    DATA_FAN_POWER,
+    DATA_FUEL_CONSUMPTION,
+    DATA_FUEL_LEVEL,
+    DATA_LOAD,
+    DATA_MODE,
+    DATA_POWER,
+    DATA_THERMOSTAT,
+    DATA_TRANSMISSION,
+]
+DEVICE_DATA.extend(alarms.ALARMS)
+DEVICE_DATA.extend(frame_versions.FRAME_VERSIONS)
+DEVICE_DATA.extend(temperatures.TEMPERATURES)
+DEVICE_DATA.extend(outputs.OUTPUTS)
+DEVICE_DATA.extend(output_flags.OUTPUT_FLAGS)
+DEVICE_DATA.extend(statuses.STATUSES)
+DEVICE_DATA.extend(lambda_.LAMBDA)
+DEVICE_DATA.extend(thermostats.THERMOSTATS)
+
 
 class Device(BaseDevice):
     """Device representation.
@@ -48,14 +81,15 @@ class Device(BaseDevice):
     Attributes:
         bucket -- frame version info storage
         mixers -- collection of device mixers
-        product -- device product type
-        uid -- device uid string
+        product -- device product info
         password -- device service password
         schema -- device regdata schema
     """
 
     def __init__(
-        self, data: Dict[str, Any] = None, parameters: Dict[str, List[int]] = None
+        self,
+        data: Optional[Dict[str, Any]] = None,
+        parameters: Optional[Dict[str, List[int]]] = None,
     ):
         """Creates device instance.
 
@@ -63,23 +97,21 @@ class Device(BaseDevice):
             data -- device data
             parameters -- editable parameters
         """
-        self.__dict__["bucket"] = FrameBucket(
-            address=self.address, required=self.required_frames
-        )
-        self.__dict__["mixers"] = MixersCollection(address=self.address)
-        self.__dict__["product"] = None
-        self.__dict__["uid"] = None
-        self.__dict__["password"] = None
-        self.__dict__["schema"] = []
+        self.bucket = FrameBucket(address=self.address, required=self.required_frames)
+        self.mixers = MixerCollection(address=self.address)
+        self.product = ProductInfo()
+        self.modules = ConnectedModules()
+        self.password = None
+        self.schema: List[Tuple[str, DataType]] = []
         super().__init__(data, parameters)
 
     def __str__(self) -> str:
         """Converts device instance to a string."""
         return f"""
-Product:        {self.product}
-Software Ver.:  {self.software}
-UID:            {self.uid}
-Password:       {self.password}
+Model:     {self.product.model}
+UID:       {self.product.uid}
+Password:  {self.password}
+Modules:   {self.modules}
 
 {super().__str__()}
 
@@ -97,8 +129,8 @@ Mixers:
             if name in DEVICE_DATA:
                 self._data[name] = value
 
-        if DATA_FRAMES in data:
-            self.bucket.fill(data[DATA_FRAMES])
+        if frame_versions.FRAME_VERSIONS in data:
+            self.bucket.fill(data[frame_versions.FRAME_VERSIONS])
 
     def set_parameters(self, parameters: Dict[str, List[int]]) -> None:
         """Sets device parameters.
@@ -107,7 +139,7 @@ Mixers:
             parameters -- device changeable parameters
         """
         for name, parameter in parameters.items():
-            if name in DEVICE_PARAMS:
+            if name in device_parameters.DEVICE_PARAMETERS:
                 self._parameters[name] = Parameter(name, *parameter)
 
     @property
@@ -118,17 +150,6 @@ Mixers:
 
         return False
 
-    @property
-    def software(self) -> Optional[str]:
-        """Returns software version."""
-        if MODULE_A in self._data:
-            if self._data[MODULE_A] is not None:
-                return self._data[MODULE_A]
-
-            return "Unknown"
-
-        return None
-
     @property
     def mode(self) -> Optional[str]:
         """Returns current mode."""
@@ -136,7 +157,7 @@ Mixers:
             if self._data[DATA_MODE] < len(MODES):
                 return MODES[self._data[DATA_MODE]]
 
-            return "Unknown"
+            return DATA_UNKNOWN
 
         return None
 
@@ -152,13 +173,13 @@ Mixers:
     def editable_parameters(self) -> List[str]:
         """Returns list of editable parameters."""
         parameters: List[str] = []
-        parameters.extend(DEVICE_PARAMS)
+        parameters.extend(device_parameters.DEVICE_PARAMETERS)
         return parameters
 
     @property
     @abstractmethod
-    def required_frames(self) -> Tuple[Type[Request], ...]:
-        """Returns tuple of required frames."""
+    def required_frames(self) -> Iterable[Type[Request]]:
+        """Returns list of required frames."""
 
 
 class EcoMAX(Device):
@@ -175,7 +196,9 @@ class EcoMAX(Device):
     _fuel_burned_timestamp: float = 0.0
 
     def __init__(
-        self, data: Dict[str, Any] = None, parameters: Dict[str, List[int]] = None
+        self,
+        data: Optional[Dict[str, Any]] = None,
+        parameters: Optional[Dict[str, List[int]]] = None,
     ):
         """Creates device instance.
 
@@ -183,8 +206,8 @@ class EcoMAX(Device):
             data -- device data
             parameters -- editable parameters
         """
-        self.__dict__["_fuel_burned"] = 0.0
-        self.__dict__["_fuel_burned_timestamp"] = time.time()
+        self._fuel_burned = 0.0
+        self._fuel_burned_timestamp = time.time()
         super().__init__(data, parameters)
 
     def set_data(self, data: Dict[str, Any]) -> None:
@@ -201,13 +224,21 @@ class EcoMAX(Device):
 
     def _set_boiler_control_parameter(self):
         """Sets boiler control parameter from device data."""
-        if PARAM_BOILER_CONTROL in self._parameters and isinstance(
-            self._parameters[PARAM_BOILER_CONTROL], Parameter
+        if (
+            device_parameters.PARAMETER_BOILER_CONTROL in self._parameters
+            and isinstance(
+                self._parameters[device_parameters.PARAMETER_BOILER_CONTROL], Parameter
+            )
         ):
-            self._parameters[PARAM_BOILER_CONTROL].value = int(self.is_on)
+            self._parameters[device_parameters.PARAMETER_BOILER_CONTROL].value = int(
+                self.is_on
+            )
         else:
-            self._parameters[PARAM_BOILER_CONTROL] = Parameter(
-                name=PARAM_BOILER_CONTROL, value=int(self.is_on), min_=0, max_=1
+            self._parameters[device_parameters.PARAMETER_BOILER_CONTROL] = Parameter(
+                name=device_parameters.PARAMETER_BOILER_CONTROL,
+                value=int(self.is_on),
+                min_value=0,
+                max_value=1,
             )
 
     def _set_fuel_burned(self, fuel_consumption: float) -> None:
@@ -229,12 +260,12 @@ class EcoMAX(Device):
         return fuel_burned
 
     @property
-    def required_frames(self) -> Tuple[Type[Request], ...]:
-        """Returns tuple of required frames."""
+    def required_frames(self) -> Iterable[Type[Request]]:
+        """Returns list of required frames."""
         return (
             requests.UID,
             requests.Password,
-            requests.Parameters,
+            requests.BoilerParameters,
             requests.MixerParameters,
         )
 
@@ -242,7 +273,7 @@ class EcoMAX(Device):
     def editable_parameters(self) -> List[str]:
         """Returns list of editable parameters."""
         parameters = super().editable_parameters
-        parameters.append(PARAM_BOILER_CONTROL)
+        parameters.append(device_parameters.PARAMETER_BOILER_CONTROL)
         return parameters
 
 
@@ -256,7 +287,7 @@ class EcoSTER(Device):
     address = ECOSTER_ADDRESS
 
 
-class DevicesCollection:
+class DeviceCollection:
     """Collection of devices.
 
     Attributes:
