@@ -2,11 +2,12 @@
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
-from typing import Any, Dict, List
+from collections.abc import Iterable
+from typing import Any, Dict, List, Optional
 
 from pyplumio import util
 from pyplumio.exceptions import UninitializedParameterError
-from pyplumio.frame import BROADCAST_ADDRESS, Request
+from pyplumio.frames import BROADCAST_ADDRESS, Request
 
 from .parameter import Parameter
 
@@ -20,9 +21,13 @@ class BaseDevice(ABC):
     """
 
     address: int = BROADCAST_ADDRESS
+    _data: Dict[str, Any] = {}
+    _parameters: Dict[str, Parameter] = {}
 
     def __init__(
-        self, data: Dict[str, Any] = None, parameters: Dict[str, List[int]] = None
+        self,
+        data: Optional[Dict[str, Any]] = None,
+        parameters: Optional[Dict[str, List[int]]] = None,
     ):
         """Creates device instance.
 
@@ -30,8 +35,8 @@ class BaseDevice(ABC):
             data -- device data
             parameters -- editable parameters
         """
-        self.__dict__["_data"] = {}
-        self.__dict__["_parameters"] = {}
+        self._data = {}
+        self._parameters = {}
 
         if data is not None:
             self.set_data(data)
@@ -77,7 +82,7 @@ class BaseDevice(ABC):
             self._queue.append(request)
 
         else:
-            raise UninitializedParameterError()
+            raise UninitializedParameterError
 
     def __repr__(self) -> str:
         """Returns serializable string representation of the class."""
@@ -140,5 +145,5 @@ Parameters:
 
     @property
     @abstractmethod
-    def editable_parameters(self) -> List[str]:
+    def editable_parameters(self) -> Iterable[str]:
         """Returns list of editable parameters."""
