@@ -1,13 +1,15 @@
 """Contains classes for mixer support."""
 from __future__ import annotations
 
+from collections.abc import Iterable
 from typing import Any, Dict, List, Optional
 
 from . import util
-from .constants import MIXER_DATA, MIXER_PARAMS
-from .frame import BROADCAST_ADDRESS, Request
+from .frames import BROADCAST_ADDRESS, Request
 from .helpers.base_device import BaseDevice
 from .helpers.parameter import Parameter
+from .structures.mixer_parameters import MIXER_PARAMETERS
+from .structures.mixers import MIXER_DATA
 
 
 class Mixer(BaseDevice):
@@ -20,8 +22,8 @@ class Mixer(BaseDevice):
 
     def __init__(
         self,
-        data: Dict[str, Any] = None,
-        parameters: Dict[str, List[int]] = None,
+        data: Optional[Dict[str, Any]] = None,
+        parameters: Optional[Dict[str, List[int]]] = None,
         index: int = 0,
     ):
         """Creates device instance.
@@ -30,8 +32,8 @@ class Mixer(BaseDevice):
             data -- device data
             parameters -- editable parameters
         """
-        self.__dict__["_index"] = index
-        self.__dict__["address"] = BROADCAST_ADDRESS
+        self._index = index
+        self.address = BROADCAST_ADDRESS
         super().__init__(data, parameters)
 
     def __repr__(self) -> str:
@@ -71,17 +73,19 @@ Parameters:
             parameters -- mixer changeable parameters
         """
         for name, parameter in parameters.items():
-            if name in MIXER_PARAMS:
-                value, min_, max_ = parameter
-                self._parameters[name] = Parameter(name, value, min_, max_, self._index)
+            if name in MIXER_PARAMETERS:
+                value, min_value, max_value = parameter
+                self._parameters[name] = Parameter(
+                    name, value, min_value, max_value, self._index
+                )
 
     @property
-    def editable_parameters(self) -> List[str]:
+    def editable_parameters(self) -> Iterable[str]:
         """Returns list of editable parameters."""
-        return MIXER_PARAMS
+        return MIXER_PARAMETERS
 
 
-class MixersCollection:
+class MixerCollection:
     """Collection of mixer devices.
 
     Attributes:
@@ -89,7 +93,9 @@ class MixersCollection:
         _mixers -- collection of mixers
     """
 
-    def __init__(self, address: int = BROADCAST_ADDRESS, mixers: List[Mixer] = None):
+    def __init__(
+        self, address: int = BROADCAST_ADDRESS, mixers: Optional[List[Mixer]] = None
+    ):
         """Creates mixer collection instance.
 
         Keyword arguments:
@@ -102,7 +108,7 @@ class MixersCollection:
 
     def __repr__(self) -> str:
         """Returns serializable string representation of the class."""
-        return f"""MixersCollection(
+        return f"""MixerCollection(
     address = {self._address},
     mixers = {self._mixers}
 )
