@@ -1,13 +1,14 @@
 """Contains frame versions structure parser."""
 
-from typing import Any, Dict, Tuple
+from typing import Any, Dict, Final, Optional, Tuple
 
 from pyplumio import util
-from pyplumio.constants import DATA_FRAMES
+
+FRAME_VERSIONS: Final = "frames"
 
 
 def from_bytes(
-    message: bytearray, offset: int = 0, data: Dict[str, Any] = None
+    message: bytearray, offset: int = 0, data: Optional[Dict[str, Any]] = None
 ) -> Tuple[Dict[str, Any], int]:
     """Parses frame message into usable data.
 
@@ -28,6 +29,6 @@ def from_bytes(
         versions[frame_type] = version
         offset += 3
 
-    data[DATA_FRAMES] = versions
+    data[FRAME_VERSIONS] = versions
 
     return data, offset
