@@ -1,13 +1,22 @@
 """Contains mixers structure parser."""
 
-from typing import Any, Dict, Tuple
+from typing import Any, Dict, Final, Optional, Tuple
 
 from pyplumio import util
-from pyplumio.constants import DATA_MIXERS, MIXER_PUMP, MIXER_TARGET, MIXER_TEMP
+from pyplumio.constants import DATA_MIXERS
+
+MIXER_TEMP: Final = "temp"
+MIXER_TARGET: Final = "target"
+MIXER_PUMP: Final = "pump"
+MIXER_DATA: Final = (
+    MIXER_TEMP,
+    MIXER_TARGET,
+    MIXER_PUMP,
+)
 
 
 def from_bytes(
-    message: bytearray, offset: int = 0, data: Dict[str, Any] = None
+    message: bytearray, offset: int = 0, data: Optional[Dict[str, Any]] = None
 ) -> Tuple[Dict[str, Any], int]:
     """Parses frame message into usable data.
 
