@@ -1,18 +1,23 @@
 """Contains output flags structure parser."""
 
-from typing import Any, Dict, Tuple
+from typing import Any, Dict, Final, Optional, Tuple
 
 from pyplumio import util
-from pyplumio.constants import (
-    DATA_CIRCULATION_PUMP_FLAG,
+
+DATA_HEATING_PUMP_FLAG: Final = "heating_pump_flag"
+DATA_WATER_HEATER_PUMP_FLAG: Final = "water_heater_pump_flag"
+DATA_CIRCULATION_PUMP_FLAG: Final = "circulation_pump_flag"
+DATA_SOLAR_PUMP_FLAG: Final = "solar_pump_flag"
+OUTPUT_FLAGS: Final = (
     DATA_HEATING_PUMP_FLAG,
-    DATA_SOLAR_PUMP_FLAG,
     DATA_WATER_HEATER_PUMP_FLAG,
+    DATA_CIRCULATION_PUMP_FLAG,
+    DATA_SOLAR_PUMP_FLAG,
 )
 
 
 def from_bytes(
-    message: bytearray, offset: int = 0, data: Dict[str, Any] = None
+    message: bytearray, offset: int = 0, data: Optional[Dict[str, Any]] = None
 ) -> Tuple[Dict[str, Any], int]:
     """Parses frame message into usable data.
 
