@@ -1,14 +1,32 @@
 """Contains outputs structure parser."""
 
 import math
-from typing import Any, Dict, Tuple
+from typing import Any, Dict, Final, Optional, Tuple
 
 from pyplumio import util
-from pyplumio.constants import OUTPUTS
+
+OUTPUTS: Final = (
+    "fan",
+    "feeder",
+    "heating_pump",
+    "water_heater_pump",
+    "ciculation_pump",
+    "lighter",
+    "alarm",
+    "outer_boiler",
+    "fan2_exhaust",
+    "feeder2",
+    "outer_feeder",
+    "solar_pump",
+    "fireplace_pump",
+    "gcz_contact",
+    "blow_fan1",
+    "blow_fan2",
+)
 
 
 def from_bytes(
-    message: bytearray, offset: int = 0, data: Dict[str, Any] = None
+    message: bytearray, offset: int = 0, data: Optional[Dict[str, Any]] = None
 ) -> Tuple[Dict[str, Any], int]:
     """Parses frame message into usable data.
 
