@@ -1,12 +1,21 @@
 """Contains outputs structure parser."""
 
-from typing import Any, Dict, Tuple
+from typing import Any, Dict, Final, Optional, Tuple
 
-from pyplumio.constants import STATUSES
+HEATING_TARGET: Final = "heating_target"
+HEATING_STATUS: Final = "heating_status"
+WATER_HEATER_TARGET: Final = "water_heater_target"
+WATER_HEATER_STATUS: Final = "water_heater_status"
+STATUSES: Final = (
+    HEATING_TARGET,
+    HEATING_STATUS,
+    WATER_HEATER_TARGET,
+    WATER_HEATER_STATUS,
+)
 
 
 def from_bytes(
-    message: bytearray, offset: int = 0, data: Dict[str, Any] = None
+    message: bytearray, offset: int = 0, data: Optional[Dict[str, Any]] = None
 ) -> Tuple[Dict[str, Any], int]:
     """Parses frame message into usable data.
 
